@@ -3,7 +3,7 @@
 
 #include <QMainWindow>
 
-#include <QtMaemo5>
+//#include <QtMaemo5>
 #include <QtWebKit>
 
 namespace Ui {
