@@ -3,7 +3,7 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.0.5";
+const QString appVersion = "1.0.6";
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
@@ -27,7 +27,7 @@ MainWindow::MainWindow(QWidget *parent) :
     qDebug()<<stationsDb.getFullStationList(StationsDB::OrderByName);
 
     loadStationsList();
-    populateList(stationsList);
+    populateList();
 
     addAction(ui->actionToggleFullscreen);
     addAction(ui->actionQuit);
@@ -297,7 +297,7 @@ void MainWindow::on_addStationButton_clicked()
     stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
     saveStationsList();
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 
 
 }
@@ -326,7 +326,7 @@ void MainWindow::on_editStationButton_clicked()
     stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
     saveStationsList();
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 
 }
 
@@ -350,20 +350,20 @@ void MainWindow::on_removeStationButton_clicked()
         stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
         saveStationsList();
         ui->stationsList->clear();
-        populateList(stationsList);
+        populateList();
     }
 
 
 }
 
-void MainWindow::populateList(QStringList list)
+void MainWindow::populateList()
 {
 
-    for (int i=0; i<list.size(); i++)
+    for (int i=0; i<stationsList.size(); i++)
     {
         QListWidgetItem *item = new QListWidgetItem(ui->stationsList);
-        item->setText(list.at(i).split("--").at(0));//+"\n"+list.at(i).split("--").at(1));
-        item->setToolTip(list.at(i).split("--").at(1));
+        item->setText(stationsList.at(i).split("--").at(0));//+"\n"+list.at(i).split("--").at(1));
+        item->setToolTip(stationsList.at(i).split("--").at(1));
 
         //item->setTextAlignment(Qt::AlignCenter);
     }
@@ -500,7 +500,7 @@ void MainWindow::on_actionAddDefaultList_triggered()
     stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
 
     saveStationsList();
-    populateList(stationsList);
+    populateList();
 
 }
 
@@ -563,7 +563,7 @@ void MainWindow::filterList(int type, QString filter, int orderBy)
         saveStationsList();
 
         ui->stationsList->clear();
-        populateList(stationsList);
+        populateList();
     }
     else
     {
@@ -572,7 +572,7 @@ void MainWindow::filterList(int type, QString filter, int orderBy)
         saveStationsList();
 
         ui->stationsList->clear();
-        populateList(stationsList);
+        populateList();
     }
 }
 
@@ -669,7 +669,7 @@ void MainWindow::on_actionDoNotFilterOrderByName_triggered()
     saveStationsList();
 
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 }
 
 void MainWindow::on_actionDoNotFilterOrderByGenre_triggered()
@@ -680,7 +680,7 @@ void MainWindow::on_actionDoNotFilterOrderByGenre_triggered()
     saveStationsList();
 
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 }
 
 void MainWindow::on_actionDoNotFilterOrderByCountry_triggered()
@@ -690,7 +690,7 @@ void MainWindow::on_actionDoNotFilterOrderByCountry_triggered()
     saveStationsList();
 
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 }
 
 
@@ -739,18 +739,82 @@ void MainWindow::on_actionGetFavouriteList_triggered()
     saveStationsList();
 
     ui->stationsList->clear();
-    populateList(stationsList);
+    populateList();
 }
 
 bool MainWindow::event(QEvent *event)
 {
-    swipeGesture->handleEvent(event);
+    //swipeGesture->handleEvent(event);
     return QWidget::event(event);
 }
 
 void MainWindow::handleSwipe(MySwipeGesture::SwipeDirection direction)
 {
     qDebug() << "swipe" << direction;
+
+    switch (direction)
+    {
+        case MySwipeGesture::Left : changeStackedWindowToLeft(); break;
+        case MySwipeGesture::Right : changeStackedWindowToRight(); break;
+    }
+}
+
+void MainWindow::changeStackedWindowToRight()
+{
+    int index = ui->stackedWidget->currentIndex();
+
+    if ( index == 3)
+    {
+        ui->stackedWidget->setCurrentIndex(0);
+    }
+    else
+    {
+        ui->stackedWidget->setCurrentIndex(++index);
+    }
+}
+
+void MainWindow::changeStackedWindowToLeft()
+{
+    int index = ui->stackedWidget->currentIndex();
+
+    if ( index == 0)
+    {
+        ui->stackedWidget->setCurrentIndex(3);
+    }
+    else
+    {
+        ui->stackedWidget->setCurrentIndex(--index);
+    }
+}
+
+void MainWindow::play()
+{
+    on_playButton_clicked();
+}
+
+void MainWindow::stop()
+{
+    on_stopButton_clicked();
+}
+
+void MainWindow::next()
+{
+    on_nextButton_clicked();
+}
+
+void MainWindow::prev()
+{
+    on_previousButton_clicked();
+}
+
+void MainWindow::hide()
+{
+    hide();
+}
+
+void MainWindow::quit()
+{
+    on_actionQuit_triggered();
 }
 
 
