@@ -41,9 +41,18 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
+    void populateList();
+    void loadStationsList();
+
 
 public slots:
     Q_SCRIPTABLE int top_application();
+    Q_SCRIPTABLE void play();
+    Q_SCRIPTABLE void stop();
+    Q_SCRIPTABLE void next();
+    Q_SCRIPTABLE void prev();
+    Q_SCRIPTABLE void hide();
+    Q_SCRIPTABLE void quit();
 
 private slots:
     void on_playButton_clicked();
@@ -82,7 +91,6 @@ private slots:
     void on_actionGetFavouriteList_triggered();
     void on_actionAddToFavourites_triggered();
     void handleSwipe(MySwipeGesture::SwipeDirection);
-
     void on_actionAddDefaultList_triggered();
 
 private:
@@ -111,12 +119,11 @@ private:
     void loadImage(QString url);
     void updateLyrics();
     void appendCronology(QString);
-    void populateList(QStringList);
     QStringList getDefaultList();
-    void loadStationsList();
     void saveStationsList();
     void connectBluetoothControl();
-
+    void changeStackedWindowToRight();
+    void changeStackedWindowToLeft();
     void closeEvent(QCloseEvent *event);
 
 protected:
